telemetryparser - Faraday Telemetry Packet Parser
======================================

This module is a collection of class objects and functions that perform actions for the Faraday "Telemetry" application, specifically parsing the packets received from a Faraday device.


.. automodule:: telemetryparser
    :members:
